# -*- Autoconf -*-
#
# M4 macros for Wannier90
#
# Copyright (C) 2010 Yann Pouillon
#
# This file is part of the Wannier90 software package. For license information,
# please see the COPYING file in the top-level directory of the source
# distribution.
#

#
# Optimizations
#



# W90_FC_OPTFLAGS()
# -----------------
#
# Sets optimization flags for the Fortran compiler.
#
AC_DEFUN([W90_FC_OPTFLAGS],[
  W90_FCOPTS=""
  W90_LDOPTS=""
  W90_LIBS=""

  case "${w90_fc_vendor}" in

    compaq)
      W90_FCOPTS="-fast"
      W90_LDOPTS="-fast"
      W90_LIBS="-lcxml"
      ;;

    g95)
      W90_FCOPTS="-O2"
      W90_LDOPTS="-O2"
      case "${with_linalg_flavor}" in
        atlas)
          W90_LIBS="-llapack -lf77blas -lcblas -latlas"
          ;;
        netlib)
          W90_LIBS="-llapack -lblas"
          ;;
      esac
      ;;

    gnu)
      W90_FCOPTS="-O2"
      W90_LDOPTS="-O2"
      case "${with_linalg_flavor}" in
        atlas)
          W90_LIBS="-llapack -lf77blas -lcblas -latlas"
          ;;
        netlib)
          W90_LIBS="-llapack -lblas"
          ;;
      esac
      ;;

    intel)
      W90_FCOPTS="-O2"
      W90_LDOPTS="-O2 -Vaxlib"
      case "${with_linalg_flavor}" in
        atlas)
          W90_LIBS="-llapack -lf77blas -lcblas -latlas"
          ;;
        mkl)
          W90_LIBS="-lmkl_lapack -lmkl_ia32 -lguide -lpthread"
          ;;
      esac
      ;;

    nag)
      W90_FCOPTS="-DNAG"
      W90_LDOPTS=""
      case "${with_linalg_flavor}" in
        atlas)
          W90_LIBS="-llapack -lf77blas -lcblas -latlas"
          ;;
        netlib)
          W90_LIBS="-llapack -lblas"
          ;;
      esac
      ;;

    pathscale)
      W90_FCOPTS="-O3"
      W90_LDOPTS=""
      W90_LIBS="-lacml"
      ;;

    pgi)
      W90_FCOPTS="-fast"
      W90_LDOPTS=""
      W90_LIBS="-llapack -lblas"
      ;;

    sun)
      W90_FCOPTS="-fast -xO3 -xlic_lib=sunperf"
      W90_LDOPTS="-fast -xO3 -xlic_lib=sunperf"
      W90_LIBS=""
      ;;

    ibm)
      W90_FCOPTS="-qfree=f90 -qsuffix=f=f90:cpp=F90 -qarch=auto -O3"
      W90_LDOPTS="-qfree=f90 -qsuffix=f=f90:cpp=F90 -qarch=auto"
      W90_LIBS="-llapack -lessl"
      ;;

    *)
      W90_FCOPTS="-O2"
      W90_LDOPTS=""
      W90_LIBS=""
      ;;

  esac

  AC_SUBST(W90_FCOPTS)
  AC_SUBST(W90_LDOPTS)
  AC_SUBST(W90_LIBS)
]) # W90_FC_OPTFLAGS
